# Changelog

## [1.3.1](https://github.com/FPGA-Research/FABulous/compare/v1.3.0...v1.3.1) (2025-09-04)


### Bug Fixes

* **docs:** RTD build broken ([#451](https://github.com/FPGA-Research/FABulous/issues/451)) ([43bb5e0](https://github.com/FPGA-Research/FABulous/commit/43bb5e0ef19ce995880bb656200b918c0b456729))
* **docs:** Switch to default RTD theme, since the old one was broken  ([#453](https://github.com/FPGA-Research/FABulous/issues/453)) ([cd9f2a8](https://github.com/FPGA-Research/FABulous/commit/cd9f2a8d3169e758346f1bc32072feb30aa9668b))
